---
name: Bug report
about: Create a report to help us improve
title: ''
labels: bug
assignees: ''

---

## Description

Add a clear and concise description of what the bug is here.

## Reproduction

Steps to reproduce the behavior:

1. Go to '...'
2. Click on '....'
3. Scroll down to '....'
4. See error

## Information

 - Python version: ...
 - `iesopt` version: ...
 - `IESopt.jl` (core) version: ...
